@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: securemem
 version: 0.1.9
-id: securemem-0.1.9-b2776257967087e0982593cb67cce3c9
-key: secur_ArobkR9k7uwJiSXmFUrDYT
+id: securemem-0.1.9-01ec912d1ae68740f3ee3b7079e4f920
+key: secur_6yuKG3yG4sMKx00Z54FnpQ
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: vincent@snarc.org
@@ -22,13 +22,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/securemem-0.1.9
 library-dirs: /usr/lib/ghc-7.10.3/site-local/securemem-0.1.9
 data-dir: /usr/share/arm-linux-ghc-7.10.3/securemem-0.1.9
-hs-libraries: HSsecuremem-0.1.9-ArobkR9k7uwJiSXmFUrDYT
+hs-libraries: HSsecuremem-0.1.9-6yuKG3yG4sMKx00Z54FnpQ
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
-    memory-0.11-3a745e41fe78387f608c420e9b455d25
+    memory-0.12-092368f288b8a5ed89de3a4f849c43f2
 haddock-interfaces: /usr/share/doc/haskell-securemem/html/securemem.haddock
 haddock-html: /usr/share/doc/haskell-securemem/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
